Enum clfft::ffi::clfftDim
[−]
[src]
#[repr(i32)]pub enum clfftDim { CLFFT_1D, CLFFT_2D, CLFFT_3D, ENDDIMENSION, }
Variants
CLFFT_1DCLFFT_2DCLFFT_3DENDDIMENSIONTrait Implementations
impl Debug for clfftDim[src]
impl Copy for clfftDim[src]
impl Clone for clfftDim[src]
fn clone(&self) -> clfftDim
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for clfftDim[src]
fn eq(&self, __arg_0: &clfftDim) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for clfftDim[src]
impl Hash for clfftDim[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
H: Hasher,
Feeds a slice of this type into the state provided.